@@ -12,15 +12,14 @@ import gen_once
 
 
 class loadOneByOneDataset(data.Dataset):
-    def __init__(self, fpath, pretrained, maxlen=510, cache=False, neg_token=False, neg_sent=False):
+
+    def __init__(self, fpath, pretrained, maxlen=510, cache=False, likelihood=''):
         sample = []
         if 'albert_chinese' in pretrained:
             tokenizer = BertTokenizer.from_pretrained(pretrained)
         else:
             tokenizer = AutoTokenizer.from_pretrained(pretrained)
-        neg_info = ""
-        neg_info += "_negtoken" if neg_token else ""
-        neg_info += "_negsent" if neg_sent else ""
+        neg_info = "_" + likelihood + "_"
         cache_path = fpath + "_maxlen" + str(maxlen) + "_" + pretrained.replace("/", "_") + neg_info + ".cache"
         if os.path.isfile(cache_path) and cache:
             with open(cache_path, "rb") as cf:
@@ -28,37 +27,47 @@ class loadOneByOneDataset(data.Dataset):
         else:
             for i in get_data_from_file(fpath):
                 tasks, task, input, target, negative_text = i
-                for j in range(1, len(target) + 1):
-                    feature = get_feature_from_data(tokenizer, maxlen, input, " ".join(target[:j - 1]),
-                                                    " ".join(target[:j]))
+                tokenized_target = tokenizer.tokenize(" ".join(target))
+                for j in range(1, len(tokenized_target) + 1):
+                    feature = get_feature_from_data(tokenizer, maxlen, input, tokenized_target[:j - 1],
+                                                    tokenized_target[:j])
                     if len(feature['input']) == len(feature['target']) == len(feature['ntarget']) == maxlen:
                         sample.append(feature)
-                    if negative_text is not None and neg_token:
+                    if negative_text is not None and 'token' in likelihood:
                         if "[SEP]" in negative_text:
                             ntext_arr = negative_text.split("[SEP]")
                         else:
                             ntext_arr = [negative_text]
                         for neg_text in ntext_arr:
                             neg_words = neg_text.split(" ")
-                            neg_word = "[SEP]" if len(neg_words) <= len(" ".join(target[:j - 1])) else neg_words[
-                                len(" ".join(target[:j - 1]))]
-                            feature = get_feature_from_data(tokenizer, maxlen, input, " ".join(target[:j - 1]),
+                            neg_word = "[SEP]" if len(neg_words) <= len(tokenized_target[:j - 1]) else \
+                                neg_words[len(tokenized_target[:j - 1])]
+                            feature = get_feature_from_data(tokenizer, maxlen, input,
+                                                            tokenized_target[:j - 1],
                                                             ntarget=neg_word)
                             if len(feature['input']) == len(feature['target']) == len(feature['ntarget']) == maxlen:
                                 sample.append(feature)
 
-                feature = get_feature_from_data(tokenizer, maxlen, input, " ".join(target), " ".join(target))
+                feature = get_feature_from_data(tokenizer, maxlen, input, tokenized_target, [tok_sep(tokenizer)])
                 if len(feature['input']) == len(feature['target']) == len(feature['ntarget']) == maxlen:
                     sample.append(feature)
 
-                if negative_text is not None and neg_sent:
+                if negative_text is not None and ('sent' in likelihood or "neg-both" in likelihood):
                     if "[SEP]" in negative_text:
                         ntext_arr = negative_text.split("[SEP]")
                     else:
                         ntext_arr = [negative_text]
                     for neg_text in ntext_arr:
-                        feature = gen_once.data_loader.get_feature_from_data(tokenizer, maxlen, input, " ".join(target),
-                                                                             ntarget=neg_text)
+                        if 'pos' in likelihood:
+                            feature = gen_once.data_loader.get_feature_from_data(tokenizer, maxlen, input,
+                                                                                 " ".join(target))
+                        elif 'neg' in likelihood:
+                            feature = gen_once.data_loader.get_feature_from_data(tokenizer, maxlen, input,
+                                                                                 ntarget=neg_text)
+                        elif 'both' in likelihood:
+                            feature = gen_once.data_loader.get_feature_from_data(tokenizer, maxlen, input,
+                                                                                 " ".join(target),
+                                                                                 ntarget=neg_text)
                         if len(feature['input']) == len(feature['target']) == len(feature['ntarget']) == maxlen:
                             sample.append(feature)
 
@@ -89,11 +98,10 @@ def get_data_from_file(fpath):
             yield tasks, task, input, target, negative_text
 
 
-def get_feature_from_data(tokenizer, maxlen, input, previous, target=None, ntarget=None):
+def get_feature_from_data(tokenizer, maxlen, input, tokenized_previous, tokenized_target=None, ntarget=None):
     row_dict = dict()
 
     tokenized_input = [tok_begin(tokenizer)] + tokenizer.tokenize(input) + [tok_sep(tokenizer)]
-    tokenized_previous = tokenizer.tokenize(previous)
     tokenized_input.extend(tokenized_previous)
     tokenized_input.append('[MASK]')
     tokenized_input_id = tokenizer.convert_tokens_to_ids(tokenized_input)
@@ -105,10 +113,7 @@ def get_feature_from_data(tokenizer, maxlen, input, previous, target=None, ntarg
     row_dict['ntarget'] = [-1] * maxlen
 
     tokenized_target_id = None
-    if target is not None:
-        tokenized_target = tokenizer.tokenize(target)
-        if previous == target:
-            tokenized_target += [tok_sep(tokenizer)]
+    if tokenized_target is not None:
         tokenized_target_id = [-1] * target_start
         tokenized_target_id.append(tokenizer.convert_tokens_to_ids(tokenized_target)[-1])
         tokenized_target_id.extend([-1] * (maxlen - len(tokenized_target_id)))
